#define DARK_BLUE		RGB(0,0,127)	// синий цвет
#define DARK_GREEN	RGB(0,127,0)	// зеленый цвет

// Идентификаторы мен\376 приложени\377

#define CM_EXIT	101
#define CM_ABOUT	102

// Сообщение WM_CONNECT
#define WM_CONNECT	WM_USER

// Размеры входной и выходной очереди
#define INQUEUE	4096
#define OUTQUEUE	4096

// ASCII-коды
#define ASCII_BELL	0x07
#define ASCII_BACK	0x08	
#define ASCII_LF		0x0A
#define ASCII_CR		0x0D

// Определ\377ем глобальные переменные только в главном модуле
#ifdef MAIN_MODULE
	HINSTANCE hInst;
	int idOpenCommPort;
#else
// Объ\377вл\377ем глобальные переменные, определенные в главном модуле
	extern int idOpenCommPort;
	extern HINSTANCE hInst;
#endif


// Объ\377вление функций
void 		About(HWND hwnd);
BOOL		InitApp(HINSTANCE hInstance);
LRESULT	UserChat(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam);
LRESULT	CALLBACK _export WndProc (HWND hWnd, UINT message,
                                  WPARAM wParam, LPARAM lParam);

// COMMSG.CPP
int ProcessCommNotify(HWND hWnd, int nComID, int nNotification);


// COMMPORT.CPP
int InitCommPort( HWND hwnd);
int CloseCommPort( int nComID );
int ReadCommPort( int nComID , LPSTR Data , int nMaxLength );
//int WriteCommPort( int nComID , LPSTR Data , int nLength );


// TTY.CPP
void InitTTY(HWND hWnd);
void WriteTTY(LPSTR lpOutString, HWND hwnd, COLORREF rgbColor);

void SetFocusTTY(HWND hwnd);
void KillFocusTTY(HWND hwnd);